@@ -1,13 +1,11 @@
 #coding: utf-8
+from django import forms
 
-from django.forms import ModelForm
 from generic_images.models import AttachedImage
 
-
-class AttachedImageForm(ModelForm):    
+class AttachedImageForm(forms.ModelForm):
     ''' Simple form for AttachedImage model with ``image`` and ``caption`` fields.'''
-    
+
     class Meta:
         model = AttachedImage
         fields = ['image', 'caption']
-        
